==> electrogram-0.2.196-py3-none-any.whl: pyrogram/raw/base/input_file_location.py <==
# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

InputFileLocation = Union["raw.types.InputDocumentFileLocation", "raw.types.InputEncryptedFileLocation", "raw.types.InputFileLocation", "raw.types.InputGroupCallStream", "raw.types.InputPeerPhotoFileLocation", "raw.types.InputPeerPhotoFileLocationLegacy", "raw.types.InputPhotoFileLocation", "raw.types.InputPhotoLegacyFileLocation", "raw.types.InputSecureFileLocation", "raw.types.InputStickerSetThumb", "raw.types.InputStickerSetThumbLegacy", "raw.types.InputTakeoutFileLocation"]


class InputFileLocation:  # type: ignore
    """Defines the location of a file for download.

    Constructors:
        This base type has 12 constructors available.

        .. currentmodule:: pyrogram.raw.types

        .. autosummary::
            :nosignatures:

            InputDocumentFileLocation
            InputEncryptedFileLocation
            InputFileLocation
            InputGroupCallStream
            InputPeerPhotoFileLocation
            InputPeerPhotoFileLocationLegacy
            InputPhotoFileLocation
            InputPhotoLegacyFileLocation
            InputSecureFileLocation
            InputStickerSetThumb
            InputStickerSetThumbLegacy
            InputTakeoutFileLocation
    """

    QUALNAME = "pyrogram.raw.base.InputFileLocation"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes")

==> electrogram-2.186.2-py3-none-any.whl: pyrogram/raw/base/input_file_location.py <==
# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

InputFileLocation = Union["raw.types.InputDocumentFileLocation", "raw.types.InputEncryptedFileLocation", "raw.types.InputFileLocation", "raw.types.InputGroupCallStream", "raw.types.InputPeerPhotoFileLocation", "raw.types.InputPhotoFileLocation", "raw.types.InputPhotoLegacyFileLocation", "raw.types.InputSecureFileLocation", "raw.types.InputStickerSetThumb", "raw.types.InputTakeoutFileLocation"]


class InputFileLocation:  # type: ignore
    """Defines the location of a file for download.

    Constructors:
        This base type has 10 constructors available.

        .. currentmodule:: pyrogram.raw.types

        .. autosummary::
            :nosignatures:

            InputDocumentFileLocation
            InputEncryptedFileLocation
            InputFileLocation
            InputGroupCallStream
            InputPeerPhotoFileLocation
            InputPhotoFileLocation
            InputPhotoLegacyFileLocation
            InputSecureFileLocation
            InputStickerSetThumb
            InputTakeoutFileLocation
    """

    QUALNAME = "pyrogram.raw.base.InputFileLocation"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes")
